<?php

/**
 * Add some more features to the child theme
 */
 
// Set up the content width value based on the theme's design and stylesheet.
if ( ! isset( $content_width ) )
	$content_width = 625;

/**
 * Load Child Theme's styles.
 *
 */

function twentytwelvechild_enqueue_styles() {
   wp_enqueue_style( 'parent-style', get_template_directory_uri() . '/style.css' );
}
add_action( 'wp_enqueue_scripts', 'twentytwelvechild_enqueue_styles' );

/**
 * Setup Child Theme's textdomain.
 *
 * Declare textdomain for this child theme.
 * Translations can be filed in the /languages/ directory.
 */
function twentytwelvechild_child_theme_setup() {
    load_child_theme_textdomain( 'twentytwelvechild', get_stylesheet_directory() . '/languages' );
}
add_action( 'after_setup_theme', 'twentytwelvechild_child_theme_setup' );


if ( ! function_exists( 'twentytwelvechild_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 *
 */
function twentytwelvechild_setup() {
	
	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );
	
	// Add two more menus
	
	register_nav_menu( 'secondary', __( 'Header', 'twentytwelvechild' ) );
	register_nav_menu( 'tertiary', __( 'Footer', 'twentytwelvechild' ) );

}
endif; // twentytwelvechild_setup
add_action( 'after_setup_theme', 'twentytwelvechild_setup', 11 );


// Register the footer widget areas
function twentytwelvechild_widgets_init() {

	register_sidebar( array(
		'name' => __( 'Footer Widget Area 1', 'twentytwelvechild' ),
		'id' => 'sidebar-4',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	register_sidebar( array(
		'name' => __( 'Footer Widget Area 2', 'twentytwelvechild' ),
		'id' => 'sidebar-5',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	register_sidebar( array(
		'name' => __( 'Footer Widget Area 3', 'twentytwelvechild' ),
		'id' => 'sidebar-6',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	register_sidebar( array(
		'name' => __( 'Footer Widget Area 4', 'twentytwelvechild' ),
		'id' => 'sidebar-7',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
}
add_action( 'widgets_init', 'twentytwelvechild_widgets_init', 11 );

/**
 * Count the number of footer sidebars to enable dynamic classes for the footer like in Standard Theme Twenty Eleven
 */
function twentytwelvechild_footer_sidebar_class() {
	$count = 0;

	if ( is_active_sidebar( 'sidebar-4' ) )
		$count++;

	if ( is_active_sidebar( 'sidebar-5' ) )
		$count++;

	if ( is_active_sidebar( 'sidebar-6' ) )
		$count++;
		
	if ( is_active_sidebar( 'sidebar-7' ) )
		$count++;

	$class = '';

	switch ( $count ) {
		case '1':
			$class = 'one';
			break;
		case '2':
			$class = 'two';
			break;
		case '3':
			$class = 'three';
			break;
		case '4':
			$class = 'four';
			break;
	}

	if ( $class )
		echo 'class="' . $class . '"';
}